Method: ActiveInteraction::Base.run
- Defined in:
- lib/active_interaction/base.rb
.run(inputs = {}) ⇒ Base
Note:
If the interaction inputs are valid and there are no runtime errors and execution completed successfully, Runnable#valid? will always return true.
Runs validations and if there are no errors it will call #execute.
|
|
# File 'lib/active_interaction/base.rb', line 39
|